@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "editorutiltest.h"
 #include "../src/editorutil.h"
-#include <QTextDocument>
 #include <QTest>
+#include <QTextDocument>
 
 EditorUtilTest::EditorUtilTest(QObject *parent)
     : QObject(parent)
@@ -24,9 +24,9 @@ void EditorUtilTest::testUpperCase_data()
     QTest::addColumn<QString>("result");
     QTest::addColumn<int>("startcursorposition");
     QTest::addColumn<int>("endcursorposition");
-    QTest::newRow("onelinewithoutselection") <<  QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
-    QTest::newRow("onelinewithselection") <<  QStringLiteral("foo") << QStringLiteral("FOO") << 0 << 3;
-    QTest::newRow("onelinewithselectionuppercase") <<  QStringLiteral("FOO") << QStringLiteral("FOO") << 0 << 3;
+    QTest::newRow("onelinewithoutselection") << QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
+    QTest::newRow("onelinewithselection") << QStringLiteral("foo") << QStringLiteral("FOO") << 0 << 3;
+    QTest::newRow("onelinewithselectionuppercase") << QStringLiteral("FOO") << QStringLiteral("FOO") << 0 << 3;
 }
 
 void EditorUtilTest::testUpperCase()
@@ -35,7 +35,7 @@ void EditorUtilTest::testUpperCase()
     QFETCH(QString, result);
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
-    auto *document = new QTextDocument(this);
+    auto document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
@@ -54,9 +54,9 @@ void EditorUtilTest::testLowerCase_data()
     QTest::addColumn<QString>("result");
     QTest::addColumn<int>("startcursorposition");
     QTest::addColumn<int>("endcursorposition");
-    QTest::newRow("onelinewithoutselection") <<  QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
-    QTest::newRow("onelinewithselection") <<  QStringLiteral("foo") << QStringLiteral("foo") << 0 << 3;
-    QTest::newRow("onelinewithselectionuppercase") <<  QStringLiteral("FOO") << QStringLiteral("foo") << 0 << 3;
+    QTest::newRow("onelinewithoutselection") << QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
+    QTest::newRow("onelinewithselection") << QStringLiteral("foo") << QStringLiteral("foo") << 0 << 3;
+    QTest::newRow("onelinewithselectionuppercase") << QStringLiteral("FOO") << QStringLiteral("foo") << 0 << 3;
 }
 
 void EditorUtilTest::testLowerCase()
@@ -65,7 +65,7 @@ void EditorUtilTest::testLowerCase()
     QFETCH(QString, result);
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
-    auto *document = new QTextDocument(this);
+    auto document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
@@ -84,9 +84,9 @@ void EditorUtilTest::testSentenceCase_data()
     QTest::addColumn<QString>("result");
     QTest::addColumn<int>("startcursorposition");
     QTest::addColumn<int>("endcursorposition");
-    QTest::newRow("onelinewithoutselection") <<  QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
-    QTest::newRow("onelinewithselection") <<  QStringLiteral("foo") << QStringLiteral("Foo") << 0 << 3;
-    QTest::newRow("bigline") <<  QStringLiteral("foo bla foo.\nddd") << QStringLiteral("Foo bla foo.\nDdd") << 0 << 16;
+    QTest::newRow("onelinewithoutselection") << QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
+    QTest::newRow("onelinewithselection") << QStringLiteral("foo") << QStringLiteral("Foo") << 0 << 3;
+    QTest::newRow("bigline") << QStringLiteral("foo bla foo.\nddd") << QStringLiteral("Foo bla foo.\nDdd") << 0 << 16;
 }
 
 void EditorUtilTest::testSentenceCase()
@@ -95,7 +95,7 @@ void EditorUtilTest::testSentenceCase()
     QFETCH(QString, result);
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
-    auto *document = new QTextDocument(this);
+    auto document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
@@ -114,10 +114,10 @@ void EditorUtilTest::testReverseCase_data()
     QTest::addColumn<QString>("result");
     QTest::addColumn<int>("startcursorposition");
     QTest::addColumn<int>("endcursorposition");
-    QTest::newRow("onelinewithoutselection") <<  QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
-    QTest::newRow("onelinewithselection") <<  QStringLiteral("foo") << QStringLiteral("FOO") << 0 << 3;
-    QTest::newRow("reverseCase") <<  QStringLiteral("fOo bla\tfOO") << QStringLiteral("FoO BLA\tFoo") << 0 << 12;
-    QTest::newRow("notallineselected") <<  QStringLiteral("fOo bla\tfOO") << QStringLiteral("FoO bla\tfOO") << 0 << 3;
+    QTest::newRow("onelinewithoutselection") << QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
+    QTest::newRow("onelinewithselection") << QStringLiteral("foo") << QStringLiteral("FOO") << 0 << 3;
+    QTest::newRow("reverseCase") << QStringLiteral("fOo bla\tfOO") << QStringLiteral("FoO BLA\tFoo") << 0 << 12;
+    QTest::newRow("notallineselected") << QStringLiteral("fOo bla\tfOO") << QStringLiteral("FoO bla\tfOO") << 0 << 3;
 }
 
 void EditorUtilTest::testReverseCase()
@@ -127,7 +127,7 @@ void EditorUtilTest::testReverseCase()
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
 
-    auto *document = new QTextDocument(this);
+    auto document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
