@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,7 +11,8 @@
 
 #include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class InsertImageWidgetPrivate;
 
 class InsertImageWidget : public QWidget
@@ -19,7 +20,7 @@ class InsertImageWidget : public QWidget
     Q_OBJECT
 public:
     explicit InsertImageWidget(QWidget *parent);
-    ~InsertImageWidget();
+    ~InsertImageWidget() override;
 
     void setImageWidth(int value);
     Q_REQUIRED_RESULT int imageWidth() const;
