@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,13 +12,14 @@
 
 #include <QTextLength>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class InsertTableWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit InsertTableWidget(QWidget *parent = nullptr);
-    ~InsertTableWidget();
+    ~InsertTableWidget() override;
     Q_REQUIRED_RESULT int columns() const;
     Q_REQUIRED_RESULT int rows() const;
     Q_REQUIRED_RESULT int border() const;
