@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,17 +8,17 @@
 #include "tableformatdialog.h"
 #include "inserttablewidget.h"
 
-#include <KLocalizedString>
-#include <QComboBox>
-#include <KSeparator>
 #include <KColorButton>
+#include <KLocalizedString>
+#include <KSeparator>
+#include <QComboBox>
 
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QSpinBox>
-#include <QLabel>
 #include <QCheckBox>
 #include <QDialogButtonBox>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QSpinBox>
+#include <QVBoxLayout>
 
 using namespace KPIMTextEdit;
 
@@ -29,10 +29,10 @@ public:
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Table Format"));
-        auto *mainLayout = new QVBoxLayout(q);
+        auto mainLayout = new QVBoxLayout(q);
 
         QWidget *page = new QWidget(q);
-        auto *lay = new QVBoxLayout(page);
+        auto lay = new QVBoxLayout(page);
         lay->setContentsMargins(0, 0, 0, 0);
         tableWidget = new InsertTableWidget;
         lay->addWidget(tableWidget);
@@ -40,7 +40,7 @@ public:
         KSeparator *sep = new KSeparator;
         lay->addWidget(sep);
 
-        auto *hbox = new QHBoxLayout;
+        auto hbox = new QHBoxLayout;
         QLabel *lab = new QLabel(i18n("Spacing:"));
         hbox->addWidget(lab);
         spacing = new QSpinBox;
