@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H
 #define ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H
 
-#include <QLocale>
-#include <QVector>
-#include <QObject>
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit {
+#include <QLocale>
+#include <QObject>
+#include <QVector>
+namespace KPIMTextEdit
+{
 /**
  * @brief The AbstractTextToSpeechConfigInterface class
  * @author Laurent Montel <montel@kde.org>
@@ -21,7 +22,7 @@ class KPIMTEXTEDIT_EXPORT AbstractTextToSpeechConfigInterface : public QObject
     Q_OBJECT
 public:
     explicit AbstractTextToSpeechConfigInterface(QObject *parent = nullptr);
-    ~AbstractTextToSpeechConfigInterface();
+    ~AbstractTextToSpeechConfigInterface() override;
     virtual Q_REQUIRED_RESULT QVector<QLocale> availableLocales() const;
     virtual Q_REQUIRED_RESULT QLocale locale() const;
     virtual void setLocale(const QLocale &locale);
