@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include "kpimtextedit_export.h"
 
 class QTextToSpeech;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 /**
  * @brief The TextToSpeechConfigInterface class
  * @author Laurent Montel <montel@kde.org>
