@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef TEXTTOSPEECHCONFIGWIDGET_H
 #define TEXTTOSPEECHCONFIGWIDGET_H
-#include <QWidget>
 #include "kpimtextedit_private_export.h"
+#include <QWidget>
 class QSlider;
 class QComboBox;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextToSpeechLanguageComboBox;
 class AbstractTextToSpeechConfigInterface;
 class KPIMTEXTEDIT_TESTS_EXPORT TextToSpeechConfigWidget : public QWidget
@@ -18,7 +19,7 @@ class KPIMTEXTEDIT_TESTS_EXPORT TextToSpeechConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit TextToSpeechConfigWidget(QWidget *parent = nullptr);
-    ~TextToSpeechConfigWidget();
+    ~TextToSpeechConfigWidget() override;
 
     void writeConfig();
     void readConfig();
